@@ -1,17 +1,19 @@
 """Task base classes for wpiformat."""
 
-import os
 import subprocess
 from abc import ABCMeta, abstractmethod
+from pathlib import Path
+
+from wpiformat.config import Config
 
 
 class Task(metaclass=ABCMeta):
     @staticmethod
-    def get_linesep(lines):
+    def get_linesep(lines: str) -> str:
         """Returns string containing autodetected line separator for file.
 
         Keyword arguments:
-        lines -- file contents string
+        lines -- file contents
         """
         # Find potential line separator
         pos = lines.find("\n")
@@ -25,24 +27,25 @@ class Task(metaclass=ABCMeta):
             return "\n"
 
     @staticmethod
-    def get_repo_root():
+    def get_repo_root() -> Path:
         """Returns the Git repository root as an absolute path.
 
-        An empty string is returned if no repository root was found.
+        Raises OSError if no repository root was found.
         """
-        return os.path.normpath(
-            subprocess.check_output(
-                ["git", "rev-parse", "--show-toplevel"], encoding="ascii"
-            ).rstrip()
-        )
+        if output := subprocess.check_output(
+            ["git", "rev-parse", "--show-toplevel"], encoding="ascii"
+        ).rstrip():
+            return Path(output).resolve()
+        else:
+            raise OSError("no Git repository root found")
 
     @staticmethod
-    def should_process_file(config_file, name):
+    def should_process_file(config_file: Config, filename: Path) -> bool:
         """Returns true if file should be processed by this task.
 
         Keyword arguments:
         config_file -- Config object
-        name -- file name string
+        filename -- filename
 
         Process any file by default.
         """
@@ -51,26 +54,28 @@ class Task(metaclass=ABCMeta):
 
 class PipelineTask(Task):
     @abstractmethod
-    def run_pipeline(self, config_file, name, lines):
+    def run_pipeline(
+        self, config_file: Config, filename: Path, lines: str
+    ) -> tuple[str, bool]:
         """Performs task on file with given lines.
 
         This function is for processing the file in a pipeline of tasks.
 
         Keyword arguments:
         config_file -- Config object
-        name -- file name string
-        lines -- file contents string
+        filename -- filename
+        lines -- file contents
 
         Returns tuple containing processed lines and whether task succeeded in
         processing the file.
         """
-        return ("", True)
+        return "", True
 
 
 class BatchTask(Task):
     @staticmethod
     @abstractmethod
-    def run_batch(config_file, names):
+    def run_batch(config_file: Config, filenames: list[Path]) -> bool:
         """Performs task on list of files.
 
         This function is for processing multiple files in one task to reduce
@@ -78,7 +83,7 @@ class BatchTask(Task):
 
         Keyword arguments:
         config_file -- Config object
-        names -- list of file name strings
+        filenames -- list of filenames
 
         Returns True if task succeeded in processing the files.
         """
@@ -87,14 +92,14 @@ class BatchTask(Task):
 
 class StandaloneTask(Task):
     @abstractmethod
-    def run_standalone(self, config_file, name):
+    def run_standalone(self, config_file: Config, filename: Path) -> bool:
         """Performs task on a file.
 
         This function is for processing the file on its own.
 
         Keyword arguments:
         config_file -- Config object
-        name -- file name string
+        filename -- filename
 
         Returns True if task succeeded in processing the file.
         """
